
# Type: derives into


holds between two distinct material entities, the old entity and the new entity, in which the new entity begins to exist when the old entity ceases to exist, and the new entity inherits the significant portion of the matter of the old entity

URI: [biolink:derives_into](https://w3id.org/biolink/vocab/derives_into)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0001001 |
|  | | SEMMEDDB:CONVERTS_TO |
| **In Subsets:** | | translator_minimal |

